package
Version:
v0.0.0-...-5586ace
Opens a new window with list of versions in this module.
Published: Oct 2, 2025
License: MIT
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type DB struct {
*sql.DB
}
func (db *DB) Event(level, code, msg string, meta map[string]interface{})
func (db *DB) Req(start time.Time, traceID, reqID, workerID, source, replyTo, rawInput, formattedInput, responseText, params, grammarUsed string,
tokIn, tokOut int, dur time.Duration, status, errStr string)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.